@@ -225,6 +225,8 @@ epsg3857 <- "+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y
 #'   Ignored if \code{project = FALSE}. See \code{\link{projectRaster}} for details.
 #' @param maxBytes the maximum number of bytes to allow for the projected image
 #'   (before base64 encoding); defaults to 4MB.
+#' @param options a list of additional options, intended to be provided by
+#'   a call to \code{\link{gridOptions}}
 #' @template data-getMapData
 #'
 #' @seealso \code{\link{addRasterLegend}} for an easy way to add a legend for a
@@ -254,6 +256,7 @@ addRasterImage <- function(
   project = TRUE,
   method = c("auto", "bilinear", "ngb"),
   maxBytes = 4 * 1024 * 1024,
+  options = gridOptions(),
   data = getMapData(map)
 ) {
   if (inherits(x, "SpatRaster")) {
@@ -268,6 +271,7 @@ addRasterImage <- function(
       project = project,
       method = method,
       maxBytes = maxBytes,
+      options = options,
       data = data
     )
   } else if (inherits(x, "RasterLayer")) {
@@ -282,6 +286,7 @@ addRasterImage <- function(
       project = project,
       method = method,
       maxBytes = maxBytes,
+      options = options,
       data = data
     )
   } else {
@@ -389,10 +394,14 @@ addRasterImage_RasterLayer <- function(
   project = TRUE,
   method = c("auto", "bilinear", "ngb"),
   maxBytes = 4 * 1024 * 1024,
+  options = gridOptions(),
   data = getMapData(map)
 ) {
 
 
+  options$opacity <- opacity
+  options$attribution <- attribution
+
   raster_is_factor <- raster::is.factor(x)
   method <- match.arg(method)
   if (method == "auto") {
@@ -444,7 +453,7 @@ addRasterImage_RasterLayer <- function(
     list(raster::ymin(bounds), raster::xmax(bounds))
   )
 
-  invokeMethod(map, data, "addRasterImage", uri, latlng, opacity, attribution, layerId, group) %>%
+  invokeMethod(map, data, "addRasterImage", uri, latlng, layerId, group, options) %>%
     expandLimits(
       c(raster::ymin(bounds), raster::ymax(bounds)),
       c(raster::xmin(bounds), raster::xmax(bounds))
@@ -462,6 +471,7 @@ addRasterImage_SpatRaster <- function(
   project = TRUE,
   method = c("auto", "bilinear", "ngb"),
   maxBytes = 4 * 1024 * 1024,
+  options = gridOptions(),
   data = getMapData(map)
 ) {
   if (!is_installed("terra", "1.6-3")) { # for terra::has.RGB()
@@ -471,6 +481,9 @@ addRasterImage_SpatRaster <- function(
     )
   }
 
+  options$opacity <- opacity
+  options$attribution <- attribution
+
   if (terra::has.RGB(x)) {
     # RGB(A) channels to color table
     x <- terra::colorize(x, "col")
@@ -548,7 +561,7 @@ addRasterImage_SpatRaster <- function(
     list(terra::ymin(bounds), terra::xmax(bounds))
   )
 
-  invokeMethod(map, data, "addRasterImage", uri, latlng, opacity, attribution, layerId, group) %>%
+  invokeMethod(map, data, "addRasterImage", uri, latlng, layerId, group, options) %>%
     expandLimits(
       c(terra::ymin(bounds), terra::ymax(bounds)),
       c(terra::xmin(bounds), terra::xmax(bounds))
@@ -639,6 +652,23 @@ tileOptions <- function(
   ))
 }
 
+#' @describeIn map-options Options for grid layers
+#' @export
+gridOptions <- function(
+  tileSize = 256,
+  updateWhenIdle = NULL,
+  zIndex = 1,
+  minZoom = 0,
+  maxZoom = NULL,
+  ...
+) {
+  filterNULL(list(
+    tileSize = tileSize, updateWhenIdle = updateWhenIdle, zIndex = zIndex,
+    minZoom = minZoom, maxZoom = maxZoom,
+    ...
+  ))
+}
+
 #' Remove elements from a map
 #'
 #' Remove one or more features from a map, identified by \code{layerId}; or,
